import { FieldState } from './FormState/types';
import { InputFieldProps } from './types';
/**
 * This hook works differently depending on whether it's inside a form state
 * context and whether it receives prop `fieldState`.
 *
 * Controlled (receiving prop `fieldState`): it will not have any local state
 * and just return the received `fieldState`.
 * This is when used like <Form><Form.Field component={MyField} /></Form>.
 *
 * Form Field (receiving prop `fieldState` and inside a form): it will connect
 * with the form and retrieve field state from the form state.
 * This is when used like <Form><MyField /></Form>.
 *
 * Standalone (not receiving prop `fieldState` and not inside a form): it will
 * have local field state and do validations by itself.
 * This is when used like <MyField />.
 */
export declare function useFieldState<V>(props: InputFieldProps<V>): {
    fieldState: FieldState<V>;
    onBlur?: InputFieldProps<V>['onBlur'];
    onFocus?: InputFieldProps<V>['onFocus'];
    onValueChange?: InputFieldProps<V>['onValueChange'];
};
