function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { if (typeof Symbol === "undefined" || !(Symbol.iterator in Object(arr))) return; var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

import React from 'react';
import styled from 'styled-components';
import { DivViewBase } from '../../../internals/web/ViewBase';
// @ts-ignore
import { getImageMeta, isPortrait } from '../utils';
import ImageLoader from './ImageLoader';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var svgDataUriPattern = /^(data:image\/svg\+xml;utf8,)(.*)/;

var useImage = function useImage(uri) {
  var _React$useState = React.useState('LOADING'),
      _React$useState2 = _slicedToArray(_React$useState, 2),
      status = _React$useState2[0],
      setStatus = _React$useState2[1];

  var _React$useState3 = React.useState(undefined),
      _React$useState4 = _slicedToArray(_React$useState3, 2),
      imageMeta = _React$useState4[0],
      setImageMeta = _React$useState4[1];

  React.useEffect(function () {
    var cancelled = false;
    var requestId = ImageLoader.load(uri, function (img) {
      getImageMeta(img).then(function (meta) {
        if (!cancelled) {
          setStatus('LOADED');
          setImageMeta(meta);
        }
      }, function () {
        if (!cancelled) {
          // ignore error, treat it as having no metadata
          setStatus('LOADED');
          setImageMeta(undefined);
        }
      });
    }, function () {
      setStatus('ERROR');
    });
    return function () {
      cancelled = true;
      ImageLoader.abort(requestId);
    };
  }, [uri]);
  return {
    status: status,
    meta: imageMeta
  };
};

export default function Image(_ref) {
  var accessibilityLabel = _ref.accessibilityLabel,
      className = _ref.className,
      source = _ref.source,
      style = _ref.style,
      testID = _ref.testID;

  var _React$useState5 = React.useState(undefined),
      _React$useState6 = _slicedToArray(_React$useState5, 2),
      layout = _React$useState6[0],
      setLayout = _React$useState6[1];

  var handleLayout = function handleLayout(event) {
    setLayout(event.nativeEvent.layout);
  };

  var formattedUri = source.uri;
  var match = source.uri.match(svgDataUriPattern); // inline SVG markup may contain characters (e.g., #, ") that need to be escaped

  if (match) {
    var _match = _slicedToArray(match, 3),
        prefix = _match[1],
        svg = _match[2];

    var encodedSvg = encodeURIComponent(svg);
    formattedUri = "".concat(prefix).concat(encodedSvg);
  }

  var _useImage = useImage(formattedUri),
      status = _useImage.status,
      meta = _useImage.meta;

  return /*#__PURE__*/_jsxs(Container, {
    className: className,
    onLayout: handleLayout,
    testID: testID,
    style: style,
    children: [layout && /*#__PURE__*/_jsx(TransformContainer, {
      $layout: layout,
      $orientation: meta && meta.Orientation,
      children: status !== 'LOADING' && /*#__PURE__*/_jsx(ImageContainer, {
        $status: status,
        $uri: formattedUri
      })
    }), /*#__PURE__*/_jsx(AccessibilityImg, {
      alt: accessibilityLabel,
      src: formattedUri
    })]
  });
}
var Container = styled(DivViewBase).withConfig({
  displayName: "Imageweb__Container",
  componentId: "sc-1jdktuz-0"
})(["overflow:hidden;"]);
var TransformContainer = styled.div.withConfig({
  displayName: "Imageweb__TransformContainer",
  componentId: "sc-1jdktuz-1"
})(["border-radius:inherit;max-height:100%;max-width:100%;position:relative;", ";", ";"], function (_ref2) {
  var $layout = _ref2.$layout,
      $orientation = _ref2.$orientation;
  return isPortrait($orientation) ? "\n    height: ".concat($layout.width, "px;\n    width: ").concat($layout.height, "px;\n  ") : "\n    height: ".concat($layout.height, "px;\n    width: ").concat($layout.width, "px;\n  ");
}, function (_ref3) {
  var $orientation = _ref3.$orientation;

  switch ($orientation) {
    case 2:
      return 'transform: scaleX(-1)';

    case 3:
      return 'transform: rotate(180deg)';

    case 4:
      return 'transform: scaleY(-1)';

    case 5:
      return 'transform: rotate(-90deg) scaleX(-1)';

    case 6:
      return 'transform: rotate(90deg)';

    case 7:
      return 'transform: rotate(90deg) scaleX(-1)';

    case 8:
      return 'transform: rotate(-90deg)';

    default:
      return '';
  }
});
var ImageContainer = styled.div.withConfig({
  displayName: "Imageweb__ImageContainer",
  componentId: "sc-1jdktuz-2"
})(["position:absolute;top:0;bottom:0;left:0;right:0;background-position:center;background-repeat:no-repeat;background-size:contain;height:100%;width:100%;", ""], function (_ref4) {
  var $status = _ref4.$status,
      $uri = _ref4.$uri;
  return $status === 'ERROR' ? "\n    background: #eee;\n  " : "\n    animation-duration: 0.3s;\n    animation-iteration-count: 1;\n    animation-timing-function: ease-in;\n    background-image: url(".concat($uri, ");\n  ");
}); // invisible. Only used to allow right click and save

var AccessibilityImg = styled.img.withConfig({
  displayName: "Imageweb__AccessibilityImg",
  componentId: "sc-1jdktuz-3"
})(["position:absolute;top:0;bottom:0;left:0;right:0;height:100%;opacity:0;width:100%;"]);