"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getActiveTextColor = exports.getActiveBorderColor = exports.getActiveBackgroundColor = exports.getFocusedTextColor = exports.getTextColor = exports.getBorderColor = exports.getFocusedBorderColor = exports.getBackgroundColor = exports.getFocusedBackgroundColor = void 0;

var _Colors = _interopRequireDefault(require("../../apis/Colors"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var getFocusedBackgroundColor = function getFocusedBackgroundColor(_ref) {
  var type = _ref.type;

  switch (type) {
    case 'primary':
      return '#FF9333';

    case 'secondary':
      return '#F2F1F1';

    case 'tertiary':
      return 'white';

    case 'destructive':
      return _Colors["default"].RED;

    default:
      return '#FF9333';
  }
};

exports.getFocusedBackgroundColor = getFocusedBackgroundColor;

var getBackgroundColor = function getBackgroundColor(_ref2) {
  var hasDisabledStyle = _ref2.hasDisabledStyle,
      loading = _ref2.loading,
      type = _ref2.type;

  if (hasDisabledStyle) {
    return '#B3B3B3';
  }

  if (loading) {
    return getFocusedBackgroundColor({
      type: type
    });
  }

  switch (type) {
    case 'primary':
      return _Colors["default"].ORANGE;

    case 'secondary':
      return 'transparent';

    case 'tertiary':
      return 'transparent';

    case 'destructive':
      return 'transparent';

    default:
      return _Colors["default"].ORANGE;
  }
};

exports.getBackgroundColor = getBackgroundColor;

var getFocusedBorderColor = function getFocusedBorderColor(_ref3) {
  var type = _ref3.type;

  switch (type) {
    case 'primary':
      return getFocusedBackgroundColor({
        type: type
      });

    case 'secondary':
      return getFocusedBackgroundColor({
        type: type
      });

    case 'tertiary':
      return '#DDDBDA';

    case 'destructive':
      return getFocusedBackgroundColor({
        type: type
      });

    default:
      return getFocusedBackgroundColor({
        type: type
      });
  }
};

exports.getFocusedBorderColor = getFocusedBorderColor;

var getBorderColor = function getBorderColor(_ref4) {
  var hasDisabledStyle = _ref4.hasDisabledStyle,
      loading = _ref4.loading,
      type = _ref4.type;

  if (hasDisabledStyle) {
    return '#B3B3B3';
  }

  if (loading) {
    return getFocusedBorderColor({
      type: type
    });
  }

  switch (type) {
    case 'primary':
      return getBackgroundColor({
        type: type
      });

    case 'secondary':
      return '#DDDBDA';

    case 'tertiary':
      return getBackgroundColor({
        type: type
      });

    case 'destructive':
      return _Colors["default"].RED;

    default:
      return getBackgroundColor({
        type: type
      });
  }
};

exports.getBorderColor = getBorderColor;

var getTextColor = function getTextColor(_ref5) {
  var hasDisabledStyle = _ref5.hasDisabledStyle,
      type = _ref5.type;

  if (hasDisabledStyle) {
    return 'white';
  }

  switch (type) {
    case 'primary':
      return 'white';

    case 'secondary':
      return _Colors["default"].BLUE;

    case 'tertiary':
      return _Colors["default"].BLUE;

    case 'destructive':
      return _Colors["default"].RED;

    default:
      return 'white';
  }
};

exports.getTextColor = getTextColor;

var getFocusedTextColor = function getFocusedTextColor(_ref6) {
  var hasDisabledStyle = _ref6.hasDisabledStyle,
      type = _ref6.type;

  if (hasDisabledStyle) {
    return 'white';
  }

  switch (type) {
    case 'primary':
      return 'white';

    case 'secondary':
      return _Colors["default"].BLUE;

    case 'tertiary':
      return _Colors["default"].BLUE;

    case 'destructive':
      return 'white';

    default:
      return 'white';
  }
};

exports.getFocusedTextColor = getFocusedTextColor;

var getActiveBackgroundColor = function getActiveBackgroundColor(_ref7) {
  var type = _ref7.type;

  switch (type) {
    case 'primary':
      return '#E36A00';

    case 'secondary':
      return _Colors["default"].BLUE;

    case 'tertiary':
      return _Colors["default"].BLUE;

    case 'destructive':
      return getFocusedBackgroundColor({
        type: type
      });

    default:
      return '#E36A00';
  }
};

exports.getActiveBackgroundColor = getActiveBackgroundColor;

var getActiveBorderColor = function getActiveBorderColor(_ref8) {
  var type = _ref8.type;

  switch (type) {
    case 'primary':
      return getActiveBackgroundColor({
        type: type
      });

    case 'secondary':
      return '#0031AC';

    case 'tertiary':
      return '#0031AC';

    case 'destructive':
      return getFocusedBorderColor({
        type: type
      });

    default:
      return getActiveBackgroundColor({
        type: type
      });
  }
};

exports.getActiveBorderColor = getActiveBorderColor;

var getActiveTextColor = function getActiveTextColor(_ref9) {
  var type = _ref9.type;
  return 'white';
};

exports.getActiveTextColor = getActiveTextColor;