"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ModalTitleContainer = exports.ModalContentContainer = exports["default"] = void 0;

var _react = _interopRequireDefault(require("react"));

var _styledComponents = _interopRequireDefault(require("styled-components"));

var _DeviceKind = require("../../../apis/DeviceKind");

var _IconButton = _interopRequireDefault(require("../../../components/IconButton"));

var _FlexDiv = _interopRequireDefault(require("../../../internals/web/FlexDiv"));

var _ViewBase = require("../../../internals/web/ViewBase");

var _Overlay = _interopRequireDefault(require("../../../primitives/Overlay"));

var _Text = _interopRequireDefault(require("../../../primitives/Text"));

var _View = _interopRequireDefault(require("../../../primitives/View"));

var _jsxRuntime = require("react/jsx-runtime");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { if (typeof Symbol === "undefined" || !(Symbol.iterator in Object(arr))) return; var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function Modal(_ref) {
  var children = _ref.children,
      _ref$hideHeader = _ref.hideHeader,
      hideHeader = _ref$hideHeader === void 0 ? false : _ref$hideHeader,
      onRequestClose = _ref.onRequestClose,
      visible = _ref.visible,
      placement = _ref.placement,
      title = _ref.title,
      renderFooter = _ref.renderFooter;
  var deviceKind = (0, _DeviceKind.useDeviceKind)();

  var _React$useState = _react["default"].useState(null),
      _React$useState2 = _slicedToArray(_React$useState, 2),
      modalContentLayout = _React$useState2[0],
      setModalContentLayout = _React$useState2[1];

  var _React$useState3 = _react["default"].useState(false),
      _React$useState4 = _slicedToArray(_React$useState3, 2),
      mouseEntered = _React$useState4[0],
      setMouseEntered = _React$useState4[1];

  var _React$useState5 = _react["default"].useState(false),
      _React$useState6 = _slicedToArray(_React$useState5, 2),
      mouseDown = _React$useState6[0],
      setMouseDown = _React$useState6[1];

  var _React$useState7 = _react["default"].useState(false),
      _React$useState8 = _slicedToArray(_React$useState7, 2),
      cancelClose = _React$useState8[0],
      setCancelClose = _React$useState8[1];

  var modalContentContainerRef = _react["default"].useRef(null);

  var prevVisibleRef = _react["default"].useRef(visible);

  _react["default"].useEffect(function () {
    if (visible && !prevVisibleRef.current) {
      var domEl = modalContentContainerRef.current;

      if (domEl && document.activeElement !== domEl && !domEl.contains(document.activeElement)) {
        // only focus if modal container or its children does not have focus
        //@ts-ignore
        document.activeElement.blur();
      }
    }

    prevVisibleRef.current = visible;
  }, [visible]);

  var onModalContentKeyDown = function onModalContentKeyDown(event) {
    if (event.keyCode === 27) {
      // escape
      event.stopPropagation();
      onRequestClose();
    }
  };

  var onModalContentLayout = function onModalContentLayout(event) {
    setModalContentLayout(event.nativeEvent.layout);
  };

  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_Overlay["default"], {
    onPress: function onPress() {
      if (!cancelClose) onRequestClose();
      setCancelClose(false);
    },
    visible: visible,
    children: /*#__PURE__*/(0, _jsxRuntime.jsxs)(ModalContentContainer, {
      $deviceKind: deviceKind,
      ref: modalContentContainerRef,
      $layout: modalContentLayout,
      onKeyDown: onModalContentKeyDown,
      onLayout: onModalContentLayout,
      $placement: placement,
      onMouseEnter: function onMouseEnter(event) {
        setMouseEntered(true);
      },
      onMouseLeave: function onMouseLeave(event) {
        setMouseEntered(false);
        setCancelClose(mouseDown);
      },
      onMouseUp: function onMouseUp(event) {
        setMouseDown(false);
        setCancelClose(mouseEntered);
      },
      onMouseDown: function onMouseDown(event) {
        setMouseDown(true);
      },
      children: [title || !hideHeader ? /*#__PURE__*/(0, _jsxRuntime.jsxs)(ModalHeader, {
        children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(ModalTitleContainer, {
          children: /*#__PURE__*/(0, _jsxRuntime.jsx)(ModalTitleText, {
            $deviceKind: deviceKind,
            children: title
          })
        }), /*#__PURE__*/(0, _jsxRuntime.jsx)(ModalCloseIcon, {
          name: "clear",
          onPress: onRequestClose
        })]
      }) : null, children, typeof renderFooter === 'function' ? /*#__PURE__*/(0, _jsxRuntime.jsx)(ModalFooter, {
        children: renderFooter()
      }) : null]
    })
  });
}

var _default = Modal;
exports["default"] = _default;
var ModalContentContainer = (0, _styledComponents["default"])(_ViewBase.DivViewBase).withConfig({
  displayName: "Modal__ModalContentContainer",
  componentId: "sc-1ms5etl-0"
})(["background-color:white;position:absolute;border-radius:4px;overflow:hidden;&:focus{outline:none;}", " ", ";"], function (props) {
  return props.$deviceKind === 'phone' || props.$deviceKind === 'large-phone' ? "\n      left: 0;\n      right: 0;\n      top: 0;\n      bottom: 0;\n      border-radius: 0px;\n      " : desktopStyle(props);
}, function (props) {
  return props.$deviceKind === 'desktop' || props.$deviceKind === 'tablet' ? "\n      @media (max-height: 768px) {\n        max-height: 100%;\n      }\n      " : '';
});
exports.ModalContentContainer = ModalContentContainer;
var ModalHeader = (0, _styledComponents["default"])(_View["default"]).withConfig({
  displayName: "Modal__ModalHeader",
  componentId: "sc-1ms5etl-1"
})(["flex:none;flex-direction:row;justify-content:space-between;background-color:white;border-bottom:1px solid #dddbda;height:55px;"]);
var ModalTitleContainer = (0, _styledComponents["default"])(_View["default"]).withConfig({
  displayName: "Modal__ModalTitleContainer",
  componentId: "sc-1ms5etl-2"
})(["align-items:center;justify-content:center;position:absolute;top:0;bottom:0;left:70px;right:70px;"]);
exports.ModalTitleContainer = ModalTitleContainer;
var ModalTitleText = (0, _styledComponents["default"])(_Text["default"]).attrs(function (props) {
  return {
    numberOfLines: 2
  };
}).withConfig({
  displayName: "Modal__ModalTitleText",
  componentId: "sc-1ms5etl-3"
})(["font-size:20px;color:#2b2826;line-height:20px;", ""], function (props) {
  return props.$deviceKind === 'phone' || props.$deviceKind === 'large-phone' ? "\n      font-size: 16px;\n      color: #2b2826;\n      line-height: 16px;\n      text-align: center;\n      " : '';
});
var ModalCloseIcon = (0, _styledComponents["default"])(_IconButton["default"]).withConfig({
  displayName: "Modal__ModalCloseIcon",
  componentId: "sc-1ms5etl-4"
})(["position:absolute;right:20px;top:15px;"]);
var ModalFooter = (0, _styledComponents["default"])(_FlexDiv["default"]).withConfig({
  displayName: "Modal__ModalFooter",
  componentId: "sc-1ms5etl-5"
})(["flex:none;flex-direction:row;justify-content:space-between;background-color:#f1f1f0;border-top:1px solid #dddbda;height:64px;padding:16px;margin-top:auto;"]);

var desktopStyle = function desktopStyle(_ref2) {
  var $layout = _ref2.$layout,
      $placement = _ref2.$placement;

  if ($placement && $placement.type === 'dropdown' && $placement.align === 'left') {
    return "\n      border-radius: 2px;\n      left: ".concat($placement.left, "px;\n      top: ").concat($placement.top, "px;\n      height: ").concat($placement.height, "px;\n      width: ").concat($placement.width, "px;        \n    ");
  }

  if ($placement && $placement.type === 'dropdown' && $placement.align === 'right') {
    return "\n      border-radius: 2px;\n      right: ".concat($placement.right, "px;\n      top: ").concat($placement.top, "px;\n      height: ").concat($placement.height, "px;\n      width: ").concat($placement.width, "px;        \n    ");
  }

  if ($placement && $placement.type === 'fullscreen') {
    return "\n      left: 0;\n      right: 0;\n      top: 0;\n      bottom: 0;\n      border-radius: 0px;\n    ";
  }

  return "\n    left: 0;\n    right: 0;\n    margin: auto;\n    max-height: 768px;\n    min-height: 200px;\n    width: 576px;\n    ".concat($layout ? "\n          top: calc(50vh - ".concat(Math.ceil($layout.height / 2), "px);\n        ") : "\n          opacity: 0;\n        ", ";\n    ");
};