"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Popover = Popover;

var _react = _interopRequireDefault(require("react"));

var _styledComponents = _interopRequireDefault(require("styled-components"));

var _DeviceKind = require("../../apis/DeviceKind");

var _Overlay = _interopRequireDefault(require("../../primitives/Overlay"));

var _ViewBase = require("../web/ViewBase");

var _jsxRuntime = require("react/jsx-runtime");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { if (typeof Symbol === "undefined" || !(Symbol.iterator in Object(arr))) return; var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function Popover(_ref) {
  var anchorEl = _ref.anchorEl,
      children = _ref.children,
      onContentMouseDown = _ref.onContentMouseDown,
      onRequestClose = _ref.onRequestClose,
      placement = _ref.placement,
      visible = _ref.visible;
  var deviceKind = (0, _DeviceKind.useDeviceKind)();

  var contentContainerRef = _react["default"].useRef(null);

  var updateContentContainerStyle = _react["default"].useCallback(function () {
    if (deviceKind === 'phone' || deviceKind === 'large-phone') {
      // We will display a full screen popup
      return;
    }

    if (!anchorEl || !contentContainerRef.current) return;

    var _calculateContentCont = calculateContentContainerStyle(anchorEl, contentContainerRef.current, createGetPopupPositionFromPlacement(placement)),
        top = _calculateContentCont.top,
        left = _calculateContentCont.left;

    contentContainerRef.current.style.top = "".concat(top, "px");
    contentContainerRef.current.style.left = "".concat(left, "px"); // Now that we know the exact position of the popup, we can show it

    contentContainerRef.current.style.opacity = '1';
  }, [anchorEl, deviceKind, placement]); // Update popup position upon open
  // 1. This component is re-rendered with visible = true
  // 2. Overlay element is added to the DOM but the content is invisible
  //    (opacity = 0)
  // 3. Effect runs and the style of the content container DOM element gets
  //    updated, making it visible in the right position


  var _React$useState = _react["default"].useState(false),
      _React$useState2 = _slicedToArray(_React$useState, 2),
      prevVisible = _React$useState2[0],
      setPrevVisible = _React$useState2[1];

  _react["default"].useEffect(function () {
    if (!prevVisible && visible) {
      updateContentContainerStyle();
    }

    if (visible !== prevVisible) {
      setPrevVisible(visible);
    }
  }, [prevVisible, visible, updateContentContainerStyle]); // Handle window resize


  _react["default"].useEffect(function () {
    var handleResize = function handleResize() {
      updateContentContainerStyle();
    };

    window.addEventListener('resize', handleResize);
    return function () {
      window.removeEventListener('resize', handleResize);
    };
  }, [updateContentContainerStyle]);

  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_Overlay["default"], {
    color: deviceKind === 'desktop' || deviceKind === 'tablet' ? 'transparent' : 'rgba(0, 0, 0, 0.5)',
    onPress: onRequestClose,
    visible: visible,
    children: /*#__PURE__*/(0, _jsxRuntime.jsx)(ContentContainer, {
      ref: contentContainerRef,
      onMouseDown: onContentMouseDown,
      $deviceKind: deviceKind,
      children: children
    })
  });
}

function calculateContentContainerStyle(anchorEl, contentContainerEl, getPopupPosition) {
  var anchorRect = anchorEl.getBoundingClientRect();
  var contentContainerRect = contentContainerEl.getBoundingClientRect();
  var popupPosition = getPopupPosition(anchorRect, contentContainerRect);
  var top = Math.min(Math.max(0, popupPosition.top), Math.floor(window.innerHeight - contentContainerRect.height));
  var left = Math.min(Math.max(0, popupPosition.left), Math.floor(window.innerWidth - contentContainerRect.width));
  return {
    top: top,
    left: left
  };
}

function createGetPopupPositionFromPlacement(placement) {
  if (!placement) {
    return function (anchorRect) {
      return {
        top: anchorRect.top,
        left: anchorRect.left
      };
    };
  }

  return placement;
}

var ContentContainer = (0, _styledComponents["default"])(_ViewBase.DivViewBase).withConfig({
  displayName: "Popoverweb__ContentContainer",
  componentId: "sc-1a7734e-0"
})(["position:absolute;background-color:white;", ""], function (_ref2) {
  var $deviceKind = _ref2.$deviceKind;
  return $deviceKind === 'desktop' || $deviceKind === 'tablet' ? "}\n    border: 1px solid #ccc;\n    box-shadow: 0 1px 0 rgba(0, 0, 0, 0.06);\n    // hide popup initially until we know its exact position\n    opacity: 0;\n  " : "\n    border-top: 1px solid #ccc;\n    box-shadow: 0 -1px 0 rgba(0, 0, 0, 0.06);\n    // grow from the bottom\n    bottom: 0;\n    left: 0;\n    right: 0;\n  ";
});