"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ScrollViewBase = void 0;

var _throttle = _interopRequireDefault(require("lodash/throttle"));

var React = _interopRequireWildcard(require("react"));

var _styledComponents = _interopRequireDefault(require("styled-components"));

var _ViewBase = require("./ViewBase");

var _jsxRuntime = require("react/jsx-runtime");

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { "default": obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj["default"] = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var ScrollViewBase = /*#__PURE__*/React.forwardRef(function (_ref, ref) {
  var accessibilityLabel = _ref.accessibilityLabel,
      children = _ref.children,
      className = _ref.className,
      horizontal = _ref.horizontal,
      onLayout = _ref.onLayout,
      style = _ref.style,
      contentContainerStyle = _ref.contentContainerStyle,
      testID = _ref.testID,
      onScroll = _ref.onScroll,
      onContentSizeChange = _ref.onContentSizeChange,
      _ref$scrollEventThrot = _ref.scrollEventThrottle,
      scrollEventThrottle = _ref$scrollEventThrot === void 0 ? 16 : _ref$scrollEventThrot;
  var styleProps = {
    className: className,
    $horizontal: horizontal,
    style: style
  };

  var onContentLayout = function onContentLayout(event) {
    var _event$nativeEvent$la = event.nativeEvent.layout,
        width = _event$nativeEvent$la.width,
        height = _event$nativeEvent$la.height;
    onContentSizeChange && onContentSizeChange(width, height);
  };

  var _onScroll = function _onScroll(event) {
    event.persist();
    onScrollThrottled(event);
  };

  var onScrollThrottled = (0, _throttle["default"])(function (event) {
    onScroll && onScroll({
      nativeEvent: {
        contentOffset: {
          x: event.currentTarget.scrollLeft,
          y: event.currentTarget.scrollTop
        },
        contentSize: {
          height: event.currentTarget.scrollHeight,
          width: event.currentTarget.scrollWidth
        },
        layoutMeasurement: {
          height: event.currentTarget.offsetHeight,
          width: event.currentTarget.offsetWidth
        }
      },
      timeStamp: Date.now()
    });
  }, scrollEventThrottle);
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(ScrollContainer, _objectSpread(_objectSpread({}, styleProps), {}, {
    accessibilityLabel: accessibilityLabel,
    ref: ref,
    onLayout: onLayout,
    onScroll: _onScroll,
    testID: testID,
    children: /*#__PURE__*/(0, _jsxRuntime.jsx)(ContentContainer, {
      $horizontal: horizontal,
      onLayout: onContentLayout,
      style: contentContainerStyle,
      children: children
    })
  }));
});
exports.ScrollViewBase = ScrollViewBase;
var ScrollContainer = (0, _styledComponents["default"])(_ViewBase.DivViewBase).withConfig({
  displayName: "ScrollViewBase__ScrollContainer",
  componentId: "z5ujgb-0"
})(["flex:1;overflow-x:hidden;overflow-y:auto;-webkit-overflow-scrolling:touch;transform:translateZ(0);", ";"], function (_ref2) {
  var $horizontal = _ref2.$horizontal;
  return $horizontal && "\n    flex-direction: row;\n    overflow-x: auto;\n    overflow-y: hidden;\n  ";
});
var ContentContainer = (0, _styledComponents["default"])(_ViewBase.DivViewBase).withConfig({
  displayName: "ScrollViewBase__ContentContainer",
  componentId: "z5ujgb-1"
})(["", ";"], function (_ref3) {
  var $horizontal = _ref3.$horizontal;
  return $horizontal ? "\n    flex-direction: row;\n    min-width: 100%;\n  " : "\n    min-height: 100%;\n  ";
});