"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = exports.createText = void 0;

var _react = _interopRequireDefault(require("react"));

var _styledComponents = _interopRequireDefault(require("styled-components"));

var _Colors = _interopRequireDefault(require("../../apis/Colors"));

var _FontContext = _interopRequireDefault(require("../../primitives/Font/FontContext"));

var _jsxRuntime = require("react/jsx-runtime");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var IsParentATextContext = /*#__PURE__*/_react["default"].createContext(false);

var createText = function createText(containerComponent) {
  var ChildText = _styledComponents["default"].div.withConfig({
    displayName: "TextBase__ChildText",
    componentId: "oydwhd-0"
  })(["box-sizing:border-box;color:", ";display:inline;flex-grow:0;flex-shrink:0;font-family:", ";font-size:", "px;position:relative;white-space:pre-wrap;word-wrap:break-word;-ms-hyphens:auto;", " ", " ", ""], _Colors["default"].BLACK, function (props) {
    return props.$fontFamilyValue;
  }, function (props) {
    return props.$fontSizeValue;
  }, function (_ref) {
    var $isParentAText = _ref.$isParentAText;
    return $isParentAText && "\n      color: inherit;\n      font-family: inherit;\n      font-size: inherit;\n      white-space: inherit;\n    ";
  }, function (_ref2) {
    var $selectable = _ref2.$selectable;
    return $selectable ? "\n      cursor: text;\n      user-select: text;\n    " : "\n      cursor: inherit;\n    ";
  }, function (_ref3) {
    var $numberOfLines = _ref3.$numberOfLines,
        $isParentAText = _ref3.$isParentAText;
    return $numberOfLines && !$isParentAText ? "\n      overflow: hidden;\n      text-overflow: ellipsis;\n      max-width: 100%;\n      ".concat($numberOfLines === 1 ? "white-space: nowrap;" : '', "\n      ").concat($numberOfLines >= 1 ? "display: -webkit-box;\n        -webkit-line-clamp: ".concat($numberOfLines, ";\n        -webkit-box-orient: vertical;") : '', "\n    ") : '';
  });

  var RootText = ChildText.withComponent(containerComponent);

  function TextBase(_ref4) {
    var accessibilityLabel = _ref4.accessibilityLabel,
        children = _ref4.children,
        className = _ref4.className,
        nativeRef = _ref4.nativeRef,
        numberOfLines = _ref4.numberOfLines,
        selectable = _ref4.selectable,
        style = _ref4.style,
        testID = _ref4.testID;

    // import after mount so that it doesn't break server-side rendering
    _react["default"].useEffect(function () {
      require('./addNonSelectableTextStyle');
    }, []);

    var isParentAText = _react["default"].useContext(IsParentATextContext);

    var _React$useContext = _react["default"].useContext(_FontContext["default"]),
        fontFamily = _React$useContext.fontFamily,
        fontSize = _React$useContext.fontSize;

    var fontSizeValue = fontSize;

    if (style && style.fontSize) {
      fontSizeValue = style.fontSize;
    }

    var styleProps = {
      className: className,
      $fontFamilyValue: fontFamily,
      $fontSizeValue: fontSizeValue,
      $isParentAText: isParentAText,
      $numberOfLines: numberOfLines,
      $selectable: selectable,
      style: style
    };

    var props = _objectSpread(_objectSpread({}, styleProps), {}, {
      'aria-label': accessibilityLabel,
      'data-testid': testID,
      ref: nativeRef
    });

    var renderChild = function renderChild(child, props) {
      if (typeof child === 'string' || typeof child === 'number') {
        return renderText(child, _objectSpread(_objectSpread({}, props), {}, {
          $isParentAText: true
        }), true);
      }

      return child;
    };

    var renderContainer = function renderContainer(children, props, isChild) {
      return /*#__PURE__*/_react["default"].createElement( // @ts-ignore
      isChild ? ChildText : RootText, props, children);
    };

    var renderText = function renderText(text, props, isChild) {
      if (selectable) {
        return renderContainer(text, props, isChild);
      } // user-select CSS property doesn't prevent the text from being copied to
      // clipboard. To avoid getting to clipboard, the text from
      // data-text-as-pseudo-element attribute will be displayed as pseudo
      // element.


      return /*#__PURE__*/_react["default"].createElement(isChild ? ChildText : RootText, _objectSpread(_objectSpread({}, props), {}, {
        'data-text-as-pseudo-element': text
      }));
    };

    var renderContent = function renderContent() {
      if (typeof children === 'string' || typeof children === 'number') {
        return renderText(children, props, false);
      }

      var flatArray = _react["default"].Children.toArray(children);

      return renderContainer(flatArray.map(function (element, index) {
        return renderChild(element, {
          key: String(index)
        });
      }), props, false);
    };

    return /*#__PURE__*/(0, _jsxRuntime.jsx)(IsParentATextContext.Provider, {
      value: true,
      children: renderContent()
    });
  }

  return /*#__PURE__*/_react["default"].forwardRef(function (props, ref) {
    return /*#__PURE__*/(0, _jsxRuntime.jsx)(TextBase, _objectSpread(_objectSpread({}, props), {}, {
      nativeRef: ref
    }));
  });
};

exports.createText = createText;

var _default = createText('div');

exports["default"] = _default;