"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useFieldState = useFieldState;

var _isEqual2 = _interopRequireDefault(require("lodash/isEqual"));

var _react = _interopRequireDefault(require("react"));

var _warning = _interopRequireDefault(require("warning"));

var _Context = require("./FormState/Context");

var _utils = require("./FormState/utils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { if (typeof Symbol === "undefined" || !(Symbol.iterator in Object(arr))) return; var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

/**
 * This hook works differently depending on whether it's inside a form state
 * context and whether it receives prop `fieldState`.
 *
 * Controlled (receiving prop `fieldState`): it will not have any local state
 * and just return the received `fieldState`.
 * This is when used like <Form><Form.Field component={MyField} /></Form>.
 *
 * Form Field (receiving prop `fieldState` and inside a form): it will connect
 * with the form and retrieve field state from the form state.
 * This is when used like <Form><MyField /></Form>.
 *
 * Standalone (not receiving prop `fieldState` and not inside a form): it will
 * have local field state and do validations by itself.
 * This is when used like <MyField />.
 */
function useFieldState(props) {
  var fieldState = props.fieldState,
      name = props.name,
      _onBlur = props.onBlur,
      _onFocus = props.onFocus,
      _onValueChange = props.onValueChange,
      validate = props.validate,
      value = props.value;
  var formState = (0, _Context.useFormState)();
  var mode = fieldState ? 'controlled' : formState && name ? 'form-field' : 'standalone';
  /* Begin form field mode */

  (0, _warning["default"])(!(formState && !name), "Field is inside a form but is regarded as a standalone field as it doesn't have the \"name\" prop."); // register validators with form

  _react["default"].useEffect(function () {
    if (mode === 'form-field' && formState && name && validate) {
      formState.actions.setFieldValidators(name, validate);
    } // TODO: We currently don't support changing field name and validators on
    // the fly.
    // eslint-disable-next-line react-hooks/exhaustive-deps

  }, []);

  var formFieldModeReturnValue = _react["default"].useMemo(function () {
    if (mode !== 'form-field' || !formState || !name) return;
    var fieldActive = formState.fieldActive,
        fieldDirty = formState.fieldDirty,
        fieldPristine = formState.fieldPristine,
        fieldTouched = formState.fieldTouched,
        fieldVisited = formState.fieldVisited,
        getFieldError = formState.getFieldError,
        getFieldValue = formState.getFieldValue,
        actions = formState.actions;
    return {
      fieldState: {
        // field state
        active: fieldActive(name),
        dirty: fieldDirty(name),
        error: getFieldError(name),
        pristine: fieldPristine(name),
        touched: fieldTouched(name),
        value: getFieldValue(name),
        visited: fieldVisited(name),
        // form state
        formState: formState
      },
      onBlur: function onBlur() {
        _onBlur && _onBlur();
        actions.blur(name);
      },
      onFocus: function onFocus() {
        _onFocus && _onFocus();
        actions.focus(name);
      },
      onValueChange: function onValueChange(value) {
        _onValueChange && _onValueChange(value);
        actions.changeValue(name, value);
      }
    };
  }, [formState, mode, name, _onBlur, _onFocus, _onValueChange]);
  /* End form field mode */

  /* Begin standalone mode */


  var _React$useReducer = _react["default"].useReducer(createFieldStateReducer(), props, function () {
    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return getInitialStandaloneState.apply(void 0, [mode].concat(args));
  }),
      _React$useReducer2 = _slicedToArray(_React$useReducer, 2),
      standaloneState = _React$useReducer2[0],
      dispatch = _React$useReducer2[1]; // validate whenever value or validator changes


  _react["default"].useEffect(function () {
    if (mode === 'standalone' && (value !== prevValueRef.current || validate !== prevValidateRef.current)) {
      dispatch({
        type: 'CHANGE_VALUE_OR_VALIDATORS',
        newValue: value,
        newValidators: validate
      });
    }
  }, [mode, validate, value]); // save previous validator


  var prevValidateRef = _react["default"].useRef(validate);

  _react["default"].useEffect(function () {
    prevValidateRef.current = validate;
  }); // save previous value


  var prevValueRef = _react["default"].useRef(value);

  _react["default"].useEffect(function () {
    prevValueRef.current = value;
  });

  var standaloneModeReturnValue = _react["default"].useMemo(function () {
    if (mode !== 'standalone') return;
    return {
      fieldState: getFieldStateFromStandaloneState(value, standaloneState),
      onBlur: function onBlur() {
        dispatch({
          type: 'BLUR'
        });
        _onBlur && _onBlur();
      },
      onFocus: function onFocus() {
        dispatch({
          type: 'FOCUS'
        });
        _onFocus && _onFocus();
      },
      onValueChange: _onValueChange
    };
  }, [mode, _onBlur, _onFocus, _onValueChange, standaloneState, value]);
  /* End standalone mode */


  return mode === 'controlled' ? {
    fieldState: fieldState,
    onBlur: _onBlur,
    onFocus: _onFocus,
    onValueChange: _onValueChange
  } : mode === 'form-field' ? formFieldModeReturnValue : standaloneModeReturnValue;
}

function createFieldStateReducer() {
  return function fieldStateReducer(state, action) {
    switch (action.type) {
      case 'BLUR':
        return _objectSpread(_objectSpread({}, state), {}, {
          touched: true
        });

      case 'CHANGE_VALUE_OR_VALIDATORS':
        {
          var oldErrors = state.errors;

          var newState = _objectSpread(_objectSpread({}, state), {}, {
            errors: []
          });

          if (action.newValidators) {
            newState.errors = validate(getFieldStateFromStandaloneState(action.newValue, newState), action.newValidators);
          }

          if ((0, _isEqual2["default"])(oldErrors, newState.errors)) {
            // Errors didn't changed. Return old state to avoid rerender.
            return state;
          }

          return newState;
        }

      case 'FOCUS':
        return _objectSpread(_objectSpread({}, state), {}, {
          visited: true
        });

      default:
        return state;
    }
  };
}

function getInitialStandaloneState(mode, props) {
  var initialState = {
    errors: [],
    initialValue: props.value == null ? undefined : props.value,
    touched: false,
    visited: false
  };

  if (mode === 'standalone' && props.validate) {
    initialState.errors = validate(getFieldStateFromStandaloneState(props.value, initialState), props.validate);
  }

  return initialState;
}

function getFieldStateFromStandaloneState(value, _ref) {
  var errors = _ref.errors,
      initialValue = _ref.initialValue,
      touched = _ref.touched,
      visited = _ref.visited;
  var pristine = (0, _utils.deepEqual)(initialValue, value);
  return {
    dirty: !pristine,
    error: errors[0],
    pristine: pristine,
    touched: touched,
    value: value,
    visited: visited
  };
}

function validate(state, validators) {
  var errors = [];

  var validateField = function validateField(validator) {
    var error = validator(state.value, state);

    if (error) {
      errors.push(error);
    }
  };

  if (Array.isArray(validators)) {
    validators.forEach(validateField);
  } else {
    validateField(validators);
  }

  return errors;
}