"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getImageMeta = getImageMeta;
exports.isPortrait = isPortrait;

var _regenerator = _interopRequireDefault(require("@babel/runtime/regenerator"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

// https://github.com/exif-js/exif-js/blob/master/exif.js
var debug = false;
var ExifTags = {
  0xa002: 'PixelXDimension',
  // Valid width of meaningful image
  0xa003: 'PixelYDimension' // Valid height of meaningful image

};
var TiffTags = {
  0x8769: 'ExifIFDPointer',
  0x0112: 'Orientation'
};

function base64ToArrayBuffer(base64, contentType) {
  contentType = contentType || base64.match(/^data:([^;]+);base64,/im)[1] || ''; // e.g. 'data:image/jpeg;base64,...' => 'image/jpeg'

  base64 = base64.replace(/^data:([^;]+);base64,/gim, '');
  var binary = atob(base64);
  var len = binary.length;
  var buffer = new ArrayBuffer(len);
  var view = new Uint8Array(buffer);

  for (var i = 0; i < len; i++) {
    view[i] = binary.charCodeAt(i);
  }

  return buffer;
}

function objectURLToBlob(url, callback) {
  var http = new XMLHttpRequest();
  http.open('GET', url, true);
  http.responseType = 'blob';

  http.onload = function (e) {
    if (this.status === 200 || this.status === 0) {
      callback(this.response);
    }
  };

  http.send();
}

function getImageMeta(_x) {
  return _getImageMeta.apply(this, arguments);
}

function _getImageMeta() {
  _getImageMeta = _asyncToGenerator( /*#__PURE__*/_regenerator["default"].mark(function _callee(img) {
    var arrayBuffer, fileReader, http, _fileReader;

    return _regenerator["default"].wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            if (!img.src) {
              _context.next = 15;
              break;
            }

            if (!/^data:/i.test(img.src)) {
              _context.next = 6;
              break;
            }

            // Data URI
            arrayBuffer = base64ToArrayBuffer(img.src);
            return _context.abrupt("return", findEXIFinJPEG(arrayBuffer));

          case 6:
            if (!/^blob:/i.test(img.src)) {
              _context.next = 11;
              break;
            }

            // Object URL
            fileReader = new FileReader();
            return _context.abrupt("return", new Promise(function (resolve, reject) {
              fileReader.onload = function (e) {
                resolve(findEXIFinJPEG(e.target.result));
              };

              fileReader.onerror = function (err) {
                reject(err);
              };

              objectURLToBlob(img.src, function (blob) {
                fileReader.readAsArrayBuffer(blob);
              });
            }));

          case 11:
            http = new XMLHttpRequest();
            return _context.abrupt("return", new Promise(function (resolve, reject) {
              http.onload = function () {
                if (this.status === 200 || this.status === 0) {
                  resolve(findEXIFinJPEG(http.response));
                } else {
                  reject(new Error('Could not load image'));
                }

                http = null;
              };

              http.onerror = function (err) {
                reject(err);
              };

              http.open('GET', img.src, true);
              http.responseType = 'arraybuffer';
              http.send(null);
            }));

          case 13:
            _context.next = 18;
            break;

          case 15:
            if (!(window.FileReader && (img instanceof window.Blob || img instanceof window.File))) {
              _context.next = 18;
              break;
            }

            _fileReader = new FileReader();
            return _context.abrupt("return", new Promise(function (resolve) {
              _fileReader.onload = function (e) {
                if (debug) console.log('Got file of length ' + e.target.result.byteLength);
                resolve(findEXIFinJPEG(e.target.result));
              };

              _fileReader.readAsArrayBuffer(img);
            }));

          case 18:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  }));
  return _getImageMeta.apply(this, arguments);
}

function findEXIFinJPEG(file) {
  var dataView = new DataView(file);
  if (debug) console.log('Got file of length ' + file.byteLength);

  if (dataView.getUint8(0) !== 0xff || dataView.getUint8(1) !== 0xd8) {
    if (debug) console.log('Not a valid JPEG');
    return undefined; // not a valid jpeg
  }

  var offset = 2;
  var length = file.byteLength;

  while (offset < length) {
    if (dataView.getUint8(offset) !== 0xff) {
      if (debug) console.log('Not a valid marker at offset ' + offset + ', found: ' + dataView.getUint8(offset));
      return undefined; // not a valid marker, something is wrong
    }

    var marker = dataView.getUint8(offset + 1);
    if (debug) console.log(marker); // we could implement handling for other markers here,
    // but we're only looking for 0xFFE1 for EXIF data

    if (marker === 225) {
      if (debug) console.log('Found 0xFFE1 marker');
      return readEXIFData(dataView, offset + 4, dataView.getUint16(offset + 2) - 2); // offset += 2 + file.getShortAt(offset+2, true);
    } else {
      offset += 2 + dataView.getUint16(offset + 2);
    }
  }
}

function readTags(file, tiffStart, dirStart, strings, bigEnd) {
  var entries = file.getUint16(dirStart, !bigEnd);
  var tags = {};

  for (var i = 0; i < entries; i++) {
    var entryOffset = dirStart + i * 12 + 2;
    var tag = strings[file.getUint16(entryOffset, !bigEnd)];

    if (tag) {
      tags[tag] = readTagValue(file, entryOffset, tiffStart, dirStart, bigEnd);
    }
  }

  return tags;
}

function readTagValue(file, entryOffset, tiffStart, dirStart, bigEnd) {
  var type = file.getUint16(entryOffset + 2, !bigEnd);
  var numValues = file.getUint32(entryOffset + 4, !bigEnd);
  var valueOffset = file.getUint32(entryOffset + 8, !bigEnd) + tiffStart;

  switch (type) {
    case 1: // byte, 8-bit unsigned int

    case 7:
      // undefined, 8-bit byte, value depending on field
      if (numValues === 1) {
        return file.getUint8(entryOffset + 8, !bigEnd);
      } else {
        var _offset = numValues > 4 ? valueOffset : entryOffset + 8;

        var vals = [];

        for (var n = 0; n < numValues; n++) {
          vals[n] = file.getUint8(_offset + n);
        }

        return vals;
      }

    case 2:
      // ascii, 8-bit byte
      var offset = numValues > 4 ? valueOffset : entryOffset + 8;
      return getStringFromDB(file, offset, numValues - 1);

    case 3:
      // short, 16 bit int
      if (numValues === 1) {
        return file.getUint16(entryOffset + 8, !bigEnd);
      } else {
        var _offset2 = numValues > 2 ? valueOffset : entryOffset + 8;

        var _vals = [];

        for (var _n = 0; _n < numValues; _n++) {
          _vals[_n] = file.getUint16(_offset2 + 2 * _n, !bigEnd);
        }

        return _vals;
      }

    case 4:
      // long, 32 bit int
      if (numValues === 1) {
        return file.getUint32(entryOffset + 8, !bigEnd);
      } else {
        var _vals2 = [];

        for (var _n2 = 0; _n2 < numValues; _n2++) {
          _vals2[_n2] = file.getUint32(valueOffset + 4 * _n2, !bigEnd);
        }

        return _vals2;
      }

    case 5:
      // rational = two long values, first is numerator, second is denominator
      if (numValues === 1) {
        var numerator = file.getUint32(valueOffset, !bigEnd);
        var denominator = file.getUint32(valueOffset + 4, !bigEnd);
        var val = new Number(numerator / denominator); // eslint-disable-line no-new-wrappers

        val.numerator = numerator;
        val.denominator = denominator;
        return val;
      } else {
        var _vals3 = [];

        for (var _n3 = 0; _n3 < numValues; _n3++) {
          var _numerator = file.getUint32(valueOffset + 8 * _n3, !bigEnd);

          var _denominator = file.getUint32(valueOffset + 4 + 8 * _n3, !bigEnd);

          _vals3[_n3] = new Number(_numerator / _denominator); // eslint-disable-line no-new-wrappers

          _vals3[_n3].numerator = _numerator;
          _vals3[_n3].denominator = _denominator;
        }

        return _vals3;
      }

    case 9:
      // slong, 32 bit signed int
      if (numValues === 1) {
        return file.getInt32(entryOffset + 8, !bigEnd);
      } else {
        var _vals4 = [];

        for (var _n4 = 0; _n4 < numValues; _n4++) {
          _vals4[_n4] = file.getInt32(valueOffset + 4 * _n4, !bigEnd);
        }

        return _vals4;
      }

    case 10:
      // signed rational, two slongs, first is numerator, second is denominator
      if (numValues === 1) {
        return file.getInt32(valueOffset, !bigEnd) / file.getInt32(valueOffset + 4, !bigEnd);
      } else {
        var _vals5 = [];

        for (var _n5 = 0; _n5 < numValues; _n5++) {
          _vals5[_n5] = file.getInt32(valueOffset + 8 * _n5, !bigEnd) / file.getInt32(valueOffset + 4 + 8 * _n5, !bigEnd);
        }

        return _vals5;
      }

    default:
      throw new Error();
  }
}

function getStringFromDB(buffer, start, length) {
  var outstr = '';

  for (var n = start; n < start + length; n++) {
    outstr += String.fromCharCode(buffer.getUint8(n));
  }

  return outstr;
}

function readEXIFData(file, start) {
  if (getStringFromDB(file, start, 4) !== 'Exif') {
    if (debug) console.log('Not valid EXIF data! ' + getStringFromDB(file, start, 4));
    return undefined;
  }

  var bigEnd;
  var tiffOffset = start + 6; // test for TIFF validity and endianness

  if (file.getUint16(tiffOffset) === 0x4949) {
    bigEnd = false;
  } else if (file.getUint16(tiffOffset) === 0x4d4d) {
    bigEnd = true;
  } else {
    if (debug) console.log('Not valid TIFF data! (no 0x4949 or 0x4D4D)');
    return undefined;
  }

  if (file.getUint16(tiffOffset + 2, !bigEnd) !== 0x002a) {
    if (debug) console.log('Not valid TIFF data! (no 0x002A)');
    return undefined;
  }

  var firstIFDOffset = file.getUint32(tiffOffset + 4, !bigEnd);

  if (firstIFDOffset < 0x00000008) {
    if (debug) console.log('Not valid TIFF data! (First offset less than 8)', file.getUint32(tiffOffset + 4, !bigEnd));
    return undefined;
  }

  var tags = readTags(file, tiffOffset, tiffOffset + firstIFDOffset, TiffTags, bigEnd);

  if (tags.ExifIFDPointer) {
    var exifData = readTags(file, tiffOffset, tiffOffset + tags.ExifIFDPointer, ExifTags, bigEnd);

    for (var tag in exifData) {
      tags[tag] = exifData[tag];
    }

    delete tags.ExifIFDPointer;
  }

  return tags;
}

function isPortrait(orientation) {
  return orientation >= 5 && orientation <= 8;
}