"use strict";

require("jest-styled-components");

require("react-testing-library/cleanup-after-each");

var _react = _interopRequireDefault(require("react"));

var _reactTestingLibrary = require("react-testing-library");

var _Style = require("../../../apis/Style");

var _ = _interopRequireDefault(require(".."));

var _jsxRuntime = require("react/jsx-runtime");

var _templateObject;

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _taggedTemplateLiteral(strings, raw) { if (!raw) { raw = strings.slice(0); } return Object.freeze(Object.defineProperties(strings, { raw: { value: Object.freeze(raw) } })); }

test('should render a div with text as a data attribute by default', function () {
  var _render = (0, _reactTestingLibrary.render)( /*#__PURE__*/(0, _jsxRuntime.jsx)(_["default"], {
    testID: "test",
    children: "hello"
  })),
      getByTestId = _render.getByTestId;

  expect(getByTestId('test')).toMatchInlineSnapshot("\n    .c0 {\n      box-sizing: border-box;\n      color: #191E26;\n      display: inline;\n      -webkit-box-flex: 0;\n      -webkit-flex-grow: 0;\n      -ms-flex-positive: 0;\n      flex-grow: 0;\n      -webkit-flex-shrink: 0;\n      -ms-flex-negative: 0;\n      flex-shrink: 0;\n      font-family: \"Helvetica Neue\",Helvetica,Arial,sans-serif;\n      font-size: 14px;\n      position: relative;\n      white-space: pre-wrap;\n      word-wrap: break-word;\n      -ms-hyphens: auto;\n      cursor: inherit;\n    }\n\n    <div\n      class=\"c0\"\n      data-testid=\"test\"\n      data-text-as-pseudo-element=\"hello\"\n    />\n  ");
});
test('should render a div with text content if selectable', function () {
  var _render2 = (0, _reactTestingLibrary.render)( /*#__PURE__*/(0, _jsxRuntime.jsx)(_["default"], {
    selectable: true,
    testID: "test",
    children: "hello"
  })),
      getByTestId = _render2.getByTestId;

  expect(getByTestId('test')).toMatchInlineSnapshot("\n    .c0 {\n      box-sizing: border-box;\n      color: #191E26;\n      display: inline;\n      -webkit-box-flex: 0;\n      -webkit-flex-grow: 0;\n      -ms-flex-positive: 0;\n      flex-grow: 0;\n      -webkit-flex-shrink: 0;\n      -ms-flex-negative: 0;\n      flex-shrink: 0;\n      font-family: \"Helvetica Neue\",Helvetica,Arial,sans-serif;\n      font-size: 14px;\n      position: relative;\n      white-space: pre-wrap;\n      word-wrap: break-word;\n      -ms-hyphens: auto;\n      cursor: text;\n      -webkit-user-select: text;\n      -moz-user-select: text;\n      -ms-user-select: text;\n      user-select: text;\n    }\n\n    <div\n      class=\"c0\"\n      data-testid=\"test\"\n    >\n      hello\n    </div>\n  ");
});
test('can render unicode characters', function () {
  // eslint-disable-next-line jsx-a11y/accessible-emoji
  var _render3 = (0, _reactTestingLibrary.render)( /*#__PURE__*/(0, _jsxRuntime.jsx)(_["default"], {
    testID: "test",
    children: "\u4F60\u597D\uD83D\uDE00"
  })),
      getByTestId = _render3.getByTestId;

  expect(getByTestId('test')).toMatchInlineSnapshot("\n    .c0 {\n      box-sizing: border-box;\n      color: #191E26;\n      display: inline;\n      -webkit-box-flex: 0;\n      -webkit-flex-grow: 0;\n      -ms-flex-positive: 0;\n      flex-grow: 0;\n      -webkit-flex-shrink: 0;\n      -ms-flex-negative: 0;\n      flex-shrink: 0;\n      font-family: \"Helvetica Neue\",Helvetica,Arial,sans-serif;\n      font-size: 14px;\n      position: relative;\n      white-space: pre-wrap;\n      word-wrap: break-word;\n      -ms-hyphens: auto;\n      cursor: inherit;\n    }\n\n    <div\n      class=\"c0\"\n      data-testid=\"test\"\n      data-text-as-pseudo-element=\"\u4F60\u597D\uD83D\uDE00\"\n    />\n  ");
});
test('can override styles using `styled`', function () {
  var StyledText = (0, _Style.styled)(_["default"])(_templateObject || (_templateObject = _taggedTemplateLiteral(["\n    font-family: Times;\n  "])));

  var _render4 = (0, _reactTestingLibrary.render)( /*#__PURE__*/(0, _jsxRuntime.jsx)(StyledText, {
    testID: "test",
    children: "hello"
  })),
      getByTestId = _render4.getByTestId;

  expect(getByTestId('test')).toMatchInlineSnapshot("\n.c0 {\n  box-sizing: border-box;\n  color: #191E26;\n  display: inline;\n  -webkit-box-flex: 0;\n  -webkit-flex-grow: 0;\n  -ms-flex-positive: 0;\n  flex-grow: 0;\n  -webkit-flex-shrink: 0;\n  -ms-flex-negative: 0;\n  flex-shrink: 0;\n  font-family: \"Helvetica Neue\",Helvetica,Arial,sans-serif;\n  font-size: 14px;\n  position: relative;\n  white-space: pre-wrap;\n  word-wrap: break-word;\n  -ms-hyphens: auto;\n  cursor: inherit;\n}\n\n.c1 {\n  font-family: Times;\n}\n\n<div\n  class=\"c0 c1\"\n  data-testid=\"test\"\n  data-text-as-pseudo-element=\"hello\"\n/>\n");
});